@@ -377,35 +377,35 @@ QString corelib::getTranslationLang(){
 
 #ifdef RELEASE
     #ifdef _OS_DARWIN_
-        QString i18nPath = QString("%1/%2.app/Contents/i18n").arg(QDir::currentPath()).arg(APP_SHORT_NAME);
+        QString l10nPath = QString("%1/%2.app/Contents/l10n").arg(QDir::currentPath()).arg(APP_SHORT_NAME);
     #else
-        QString i18nPath = QString("%1/share/%2/i18n").arg(QString::fromUtf8(APP_PREF)).arg(APP_SHORT_NAME);
+        QString l10nPath = QString("%1/share/%2/l10n").arg(QString::fromUtf8(APP_PREF)).arg(APP_SHORT_NAME);
     #endif
 #else
-    QString i18nPath = QString("%1/i18n").arg(QString::fromUtf8(APP_BUILD));
+    QString l10nPath = QString("%1/l10n").arg(QString::fromUtf8(APP_BUILD));
 #endif
 
 
 
 #ifdef DEBUG
-    qDebug()<<"[ii] i18n path: "<<i18nPath;
+    qDebug()<<"[ii] l10n path: "<<l10nPath;
 #endif
 
     QString lang = this->getLang();
 
     if (!lang.isNull()){
-        if (qtt.load(lang, i18nPath)){
+        if (qtt.load(lang, l10nPath)){
             qDebug()<<"[ii] Loading translation: "<<lang;
             return lang;
         } else {
             qDebug()<<"[EE] Cannot open user selected translation: "<<lang;
             lang = this->getLang(false);
-            if (qtt.load(lang, i18nPath)){
+            if (qtt.load(lang, l10nPath)){
                 qDebug()<<"[ii] Loading translation: "<<lang;
                 return lang;
             } else {
                 qDebug()<<"[EE] Cannot open system selected translation: "<<lang;
-                if (qtt.load("q4wine_en", i18nPath)){
+                if (qtt.load("q4wine_en", l10nPath)){
                     qDebug()<<"[ii] Loading translation: q4wine_en"<<lang;
                     return "q4wine_en";
                 } else {
@@ -868,7 +868,7 @@ QStringList corelib::getCdromDevices(void) const{
             return image;
         }
 
-        bool corelib::runIcon(const QString prefix_name, const QString dir_name, const QString icon_name){
+        bool corelib::runIcon(const QString prefix_name, const QString dir_name, const QString icon_name, const QStringList extra_args){
             QHash<QString, QString> result = db_icon.getByName(prefix_name, dir_name, icon_name);
             ExecObject execObj;
             execObj.wrkdir = result.value("wrkdir");
@@ -876,7 +876,11 @@ QStringList corelib::getCdromDevices(void) const{
             execObj.winedebug = result.value("winedebug");
             execObj.useconsole = result.value("useconsole");
             execObj.display = result.value("display");
-            execObj.cmdargs = result.value("cmdargs");
+            if (extra_args.isEmpty()){
+                execObj.cmdargs = result.value("cmdargs");
+            } else {
+                execObj.cmdargs = QString("%1 %2").arg(result.value("cmdargs")).arg(extra_args.join(" "));
+            }
             execObj.execcmd = result.value("exec");
             execObj.desktop = result.value("desktop");
             execObj.nice = result.value("nice");
@@ -1065,7 +1069,7 @@ QStringList corelib::getCdromDevices(void) const{
             out<<"Exec="<<QString::fromUtf8(APP_PREF)<<"/bin/q4wine-cli -p \""<<prefix_name<<"\" ";
             if (!dir_name.isEmpty())
                 out<<" -d \""<<dir_name<<"\" ";
-            out<<" -i \""<<icon_name<<"\" "<<endl;
+            out<<" -i \""<<icon_name<<"\" "<<" %f"<<endl;
 
             QString icon_path = result.value("icon_path");
 
@@ -1109,6 +1113,10 @@ QStringList corelib::getCdromDevices(void) const{
             out<<"Type=Application"<<endl;
             out<<"StartupNotify=true"<<endl;
             out<<"GenericName="<<icon_name<<endl;
+            QString desc = result.value("desc");
+            if (!desc.isEmpty()) {
+                out<<"Comment="<<desc<<endl;
+            }
             out<<"Name="<<icon_name<<endl;
             out<<"Path="<<result.value("wrkdir")<<endl;
 
